@@ -91,6 +91,7 @@ module.exports=function(db,config,validator,jvm,manifest){
                 if(urls.length==3){
                     nurl=nurl+"/";
                 }
+                console.log(nurl);
                 require(re_url)(app);
                 req.url=nurl;
             }
@@ -133,10 +134,11 @@ module.exports=function(db,config,validator,jvm,manifest){
     //config static
     app.use(express.static(work_dir+'/public'));
 
-    app.use(function(req, res) {
-      var url = req.url;
+    //app.use(function(req, res) {
+     // var url = req.url;
       
-      res.sendFile(work_dir+'/public/index.html',404);
-    });
+    //  res.sendFile(work_dir+'/public/index.html',404);
+     // next();
+  //  });
     return app;
 }
\ No newline at end of file
